@@ -561,7 +561,7 @@ create_password_dialog (const gchar* prompt)
 							"anjuta");
 	hbox = gtk_hbox_new (FALSE, 10);
 	gtk_widget_show (hbox);
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), hbox);
+	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG(dialog))), hbox);
 	
 	icon = anjuta_res_get_image (ANJUTA_PIXMAP_PASSWORD);
 	gtk_widget_show (icon);
@@ -965,9 +965,23 @@ anjuta_launcher_execution_done_cleanup (AnjutaLauncher *launcher,
 	if (launcher->priv->pty_output_buffer)
 		g_free (launcher->priv->pty_output_buffer);
 	if (launcher->priv->stdout_buffer)
+	{
+		/* Send remaining data if last line is not terminated with EOL */
+		(launcher->priv->output_callback)(launcher,
+			       ANJUTA_LAUNCHER_OUTPUT_STDOUT,
+			       launcher->priv->stdout_buffer,
+			       launcher->priv->callback_data);
 		g_free (launcher->priv->stdout_buffer);
+	}
 	if (launcher->priv->stderr_buffer)
+	{
+		/* Send remaining data if last line is not terminated with EOL */
+		(launcher->priv->output_callback)(launcher,
+			       ANJUTA_LAUNCHER_OUTPUT_STDERR,
+			       launcher->priv->stderr_buffer,
+			       launcher->priv->callback_data);
 		g_free (launcher->priv->stdout_buffer);
+	}
 	
 	/* Save them before we re-initialize */
 	child_status = launcher->priv->child_status;
