@@ -1322,10 +1322,6 @@ build_execute_command_in_context (BuildContext* context, GError **err)
 	/* Send options to make */
 	if (strcmp (build_program_get_basename (context->program), "make") == 0)
 	{
-		if (!anjuta_preferences_get_bool (prefs , PREF_TRANSLATE_MESSAGE))
-		{
-			build_program_add_env (context->program, "LANGUAGE", "C");
-		}
 		if (anjuta_preferences_get_bool (prefs , PREF_PARALLEL_MAKE))
 		{
 			gchar *arg = g_strdup_printf ("-j%d", anjuta_preferences_get_int (prefs , PREF_PARALLEL_MAKE_JOB));
@@ -1338,6 +1334,14 @@ build_execute_command_in_context (BuildContext* context, GError **err)
 		}
 	}
 	
+	/* Set a current working directory which can contains symbolic links */
+	build_program_add_env (context->program, "PWD", context->program->work_dir);
+
+	if (!anjuta_preferences_get_bool (prefs , PREF_TRANSLATE_MESSAGE))
+	{
+		build_program_add_env (context->program, "LANGUAGE", "C");
+	}
+	
 	build_program_override (context->program, context->environment);
 	
 	if (context->message_view)
@@ -2016,6 +2020,10 @@ build_configure_dialog (BasicAutotoolsPlugin *plugin, BuildFunc func, const gcha
 	run_autogen = !directory_has_file (plugin->project_root_dir, "configure");
 	
 	anjuta_shell_get_value (ANJUTA_PLUGIN (plugin)->shell, IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI, &value, NULL);
+
+	/* In case, a project is not loaded */
+	if (!G_VALUE_HOLDS_STRING (&value)) return;
+
 	project_root = g_value_get_string (&value);
 	parent = GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell);
 
@@ -2036,7 +2044,7 @@ build_configure_dialog (BasicAutotoolsPlugin *plugin, BuildFunc func, const gcha
 	
 		build_dir = g_file_get_path (file);
 		g_object_unref (file);
-	
+
 		args = build_configuration_get_args (config);
 		
 		if (run_autogen)
@@ -2088,7 +2096,7 @@ build_configure_and_build (BasicAutotoolsPlugin *plugin, BuildFunc func, const g
 	has_makefile = directory_has_makefile (build_dir);
 	g_free (build_dir);
 
-	if (!has_makefile)
+	if (!has_makefile && (plugin->project_root_dir != NULL))
 	{
 		/* Run configure first */
 		build_configure_dialog (plugin, func, name);
@@ -2124,7 +2132,7 @@ static const gchar*
 build_get_uri_configuration (BasicAutotoolsPlugin *plugin, const gchar *uri)
 {
 	BuildConfiguration *cfg;
-	BuildConfiguration *uri_cfg;
+	BuildConfiguration *uri_cfg = NULL;
 	gsize uri_len = 0;
 
 	/* Check all configurations as other configuration directories are
