@@ -38,23 +38,33 @@ extern GType class_inheritance_get_type (GTypeModule *module);
 #define ANJUTA_IS_PLUGIN_CLASS_INHERITANCE_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), ANJUTA_TYPE_PLUGIN_CLASS_INHERITANCE))
 #define ANJUTA_PLUGIN_CLASS_INHERITANCE_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), ANJUTA_TYPE_PLUGIN_CLASS_INHERITANCE, AnjutaClassInheritanceClass))
 
-
 typedef struct _AnjutaClassInheritance AnjutaClassInheritance;
 typedef struct _AnjutaClassInheritanceClass AnjutaClassInheritanceClass;
 
+enum {
+	STYLE_BG,
+	STYLE_FG,
+	STYLE_TITLE_BG,
+	STYLE_TITLE_FG,
+	STYLE_TITLE_PRELIGHT_FG,
+	STYLE_TITLE_PRELIGHT_BG,
+	STYLE_ITEM_BG,
+	STYLE_ITEM_FG,
+	STYLE_ITEM_PRELIGHT_FG,
+	STYLE_ITEM_PRELIGHT_BG,
+	N_STYLES
+};
+
 struct _AnjutaClassInheritance {
 	AnjutaPlugin parent;
 	
-	GtkWidget *widget;        /* a vbox */
+	GtkWidget *widget; /* a vbox */
 	GtkWidget *update_button;	
 	GtkWidget *menu;
 	GtkWidget *update;
 	
 	GtkWidget *canvas;
-	GList *drawable_list;   		/* GnomeCanvasItem* list. Edges, arrows and texts */
-	GList *node_list;					/* NodeData* list */
-
-	GTree *expansion_node_list;	/* expansion_status for the nodes */
+	GHashTable *nodes;
 
 	/* graphviz stuff */	
 	GVC_t *gvc;
@@ -63,6 +73,9 @@ struct _AnjutaClassInheritance {
 	gchar *top_dir;
 	guint root_watch_id;
 	gint uiid;
+	
+	/* Style colors */
+	GdkColor style[N_STYLES];
 };
 
 struct _AnjutaClassInheritanceClass {
