@@ -278,12 +278,34 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 		self->current_editor = NULL;
 		return;
 	}
-							 
+
 	self->current_editor = IANJUTA_EDITOR (editor);
 	g_object_add_weak_pointer (G_OBJECT (self->current_editor), (gpointer *)(gpointer)&self->current_editor);
 		
 	/* Restore program counter marker */
 	show_program_counter_in_editor (self);
+
+	/* connect signal to enable/disable breakpoints on double clicking the line marks gutter */
+	/* firstly, find the handler of previously connected signal */
+	/* secondly, connect signal if a handler wasn't found for the signal */
+	guint signal_id = g_signal_lookup( "line-marks-gutter-clicked", IANJUTA_TYPE_EDITOR);
+	glong handler_id = g_signal_handler_find( (gpointer)self->current_editor,
+            G_SIGNAL_MATCH_ID,
+            signal_id,
+            0, NULL, NULL, NULL );
+
+
+	DEBUG_PRINT("current editor %p, breapoints db %p", self->current_editor, self->breakpoints);
+
+	if(!handler_id) {
+		g_signal_connect (
+				self->current_editor,
+				"line-marks-gutter-clicked",
+				G_CALLBACK (breakpoint_toggle_handler),
+				self->breakpoints
+			);
+	}
+
 }
 
 static void
@@ -1182,7 +1204,7 @@ dma_plugin_deactivate (AnjutaPlugin* plugin)
 	/* Stop debugger */
 	dma_plugin_debugger_stopped (this, 0);
 
-	g_signal_handlers_disconnect_matched (plugin->shell, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, plugin);	
+	g_signal_handlers_disconnect_by_func (plugin->shell, G_CALLBACK (on_session_save), plugin);
 	g_signal_handlers_disconnect_matched (plugin, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, plugin);	
 
 	anjuta_plugin_remove_watch (plugin, this->project_watch_id, FALSE);
