@@ -48,22 +48,22 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:STRING,BOOLEAN,INT,INT (file-view-marshal.list:1) */
+/* VOID:OBJECT,BOOLEAN,INT,INT (./file-view-marshal.list:1) */
 void
-file_view_cclosure_marshal_VOID__STRING_BOOLEAN_INT_INT (GClosure     *closure,
-                                                         GValue       *return_value,
+file_view_cclosure_marshal_VOID__OBJECT_BOOLEAN_INT_INT (GClosure     *closure,
+                                                         GValue       *return_value G_GNUC_UNUSED,
                                                          guint         n_param_values,
                                                          const GValue *param_values,
-                                                         gpointer      invocation_hint,
+                                                         gpointer      invocation_hint G_GNUC_UNUSED,
                                                          gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__STRING_BOOLEAN_INT_INT) (gpointer     data1,
+  typedef void (*GMarshalFunc_VOID__OBJECT_BOOLEAN_INT_INT) (gpointer     data1,
                                                              gpointer     arg_1,
                                                              gboolean     arg_2,
                                                              gint         arg_3,
                                                              gint         arg_4,
                                                              gpointer     data2);
-  register GMarshalFunc_VOID__STRING_BOOLEAN_INT_INT callback;
+  register GMarshalFunc_VOID__OBJECT_BOOLEAN_INT_INT callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
 
@@ -79,10 +79,10 @@ file_view_cclosure_marshal_VOID__STRING_BOOLEAN_INT_INT (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_VOID__STRING_BOOLEAN_INT_INT) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_VOID__OBJECT_BOOLEAN_INT_INT) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_marshal_value_peek_string (param_values + 1),
+            g_marshal_value_peek_object (param_values + 1),
             g_marshal_value_peek_boolean (param_values + 2),
             g_marshal_value_peek_int (param_values + 3),
             g_marshal_value_peek_int (param_values + 4),
