@@ -49,6 +49,7 @@ struct _NPWPage
 	gchar* name;
 	gchar* label;
 	gchar* description;
+	gint language;
 	GtkWidget *widget;
 };
 
@@ -59,6 +60,7 @@ struct _NPWProperty {
 	gchar* label;
 	gchar* description;
 	gchar* defvalue;
+	gint language;
 	NPWValue* value;
 	GtkWidget* widget;
 	GSList* items;
@@ -67,6 +69,7 @@ struct _NPWProperty {
 struct _NPWItem {
 	gchar* name;
 	gchar* label;
+	gint language;
 };
 
 static const gchar* NPWPropertyTypeString[] = {
@@ -89,13 +92,14 @@ static const gchar* NPWPropertyRestrictionString[] = {
  *---------------------------------------------------------------------------*/
 
 static NPWItem*
-npw_item_new (const gchar *name, const gchar *label)
+npw_item_new (const gchar *name, const gchar *label, gint language)
 {
 	NPWItem *item;
 	
 	item = g_slice_new (NPWItem);
 	item->name = g_strdup (name);
 	item->label = g_strdup (label);
+	item->language = language;
 	
 	return item;
 }
@@ -108,6 +112,18 @@ npw_item_free (NPWItem *item)
 	g_slice_free (NPWItem, item);
 }
 
+static gint
+npw_item_compare (const NPWItem *a, const NPWItem *b)
+{
+	return g_strcmp0 (a->name, b->name);
+}
+
+static const gchar *
+npw_item_get_label (const NPWItem *item)
+{
+	return item->language == 0 ? _(item->label) : item->label;
+}
+
 /* Property object
  *---------------------------------------------------------------------------*/
 
@@ -147,6 +163,12 @@ npw_property_restriction_from_string (const gchar* restriction)
 	return NPW_NO_RESTRICTION;
 }
 
+static gint
+npw_property_compare (const NPWProperty *a, const NPWProperty *b)
+{
+	return g_strcmp0 (npw_value_get_name (a->value), npw_value_get_name (b->value));
+}
+
 NPWProperty*
 npw_property_new (void)
 {
@@ -174,6 +196,12 @@ npw_property_free (NPWProperty* prop)
 	g_slice_free (NPWProperty, prop);
 }
 
+void
+npw_property_set_language (NPWProperty* prop, gint language)
+{
+	prop->language = language;
+}
+
 void
 npw_property_set_type (NPWProperty* prop, NPWPropertyType type)
 {
@@ -281,25 +309,27 @@ npw_property_get_name (const NPWProperty* prop)
 void
 npw_property_set_label (NPWProperty* prop, const gchar* label)
 {
+	g_free (prop->label);
 	prop->label = g_strdup (label);
 }
 
 const gchar*
 npw_property_get_label (const NPWProperty* prop)
 {
-	return prop->label;
+	return prop->language == 0 ? _(prop->label) : prop->label;
 }
 
 void
 npw_property_set_description (NPWProperty* prop, const gchar* description)
 {
+	g_free (prop->description);
 	prop->description = g_strdup (description);
 }
 
 const gchar*
 npw_property_get_description (const NPWProperty* prop)
 {
-	return prop->description;
+	return prop->language == 0 ? _(prop->description) : prop->description;
 }
 
 static void
@@ -509,10 +539,10 @@ npw_property_create_widget (NPWProperty* prop)
 		entry = gtk_combo_box_entry_new_text ();
 		for (node = prop->items; node != NULL; node = node->next)
 		{
-			gtk_combo_box_append_text (GTK_COMBO_BOX (entry), _(((NPWItem *)node->data)->label));
+			gtk_combo_box_append_text (GTK_COMBO_BOX (entry), npw_item_get_label((NPWItem *)node->data));
 			if ((value != NULL) && !get_value && (strcmp (value, ((NPWItem *)node->data)->name) == 0))
 			{
-				value = _(((NPWItem *)node->data)->label);
+				value = npw_item_get_label ((NPWItem *)node->data);
 				get_value = TRUE;
 			}
 		}
@@ -566,6 +596,7 @@ npw_property_set_default (NPWProperty* prop, const gchar* value)
 				sprintf(buffer,"%s%d",value, i);
 				if (!g_file_test (buffer, G_FILE_TEST_EXISTS)) break;
 			}
+			g_free (prop->defvalue);
 			prop->defvalue = buffer;
 			g_free (expand_value);
 
@@ -577,6 +608,7 @@ npw_property_set_default (NPWProperty* prop, const gchar* value)
 	 * the default property */
 	if (prop->defvalue != value)
 	{
+		g_free (prop->defvalue);
 		prop->defvalue = (value == NULL) ? NULL : g_strdup (value);
 	}
 }
@@ -628,7 +660,7 @@ npw_property_set_value_from_widget (NPWProperty* prop, NPWValueTag tag)
 		value = gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (prop->widget))));
 		for (node = prop->items; node != NULL; node = node->next)
 		{
-			if (strcmp (value, _(((NPWItem *)node->data)->label)) == 0)
+			if (strcmp (value, npw_item_get_label((NPWItem *)node->data)) == 0)
 			{
 				value = ((NPWItem *)node->data)->name;
 				break;
@@ -690,12 +722,31 @@ npw_property_get_value (const NPWProperty* prop)
 }
 
 gboolean
-npw_property_add_list_item (NPWProperty* prop, const gchar* name, const gchar* label)
+npw_property_add_list_item (NPWProperty* prop, const gchar* name, const gchar* label, gint language)
 {
 	NPWItem* item;
+	GSList *find;
 
-	item = npw_item_new (name, label);
-	prop->items = g_slist_append (prop->items, item);
+	item = npw_item_new (name, label, language);
+	find = g_slist_find_custom (prop->items, item, (GCompareFunc)npw_item_compare);
+	if (find != NULL)
+	{
+		NPWItem* old_item = (NPWItem *)find->data;
+		
+		if (old_item->language <= item->language)
+		{
+			npw_item_free ((NPWItem *)find->data);
+			find->data = item;
+		}
+		else
+		{
+			npw_item_free (item);
+		}
+	}
+	else
+	{
+		prop->items = g_slist_append (prop->items, item);
+	}
 
 	return TRUE;
 }
@@ -800,6 +851,7 @@ npw_page_free (NPWPage* page)
 void
 npw_page_set_name (NPWPage* page, const gchar* name)
 {
+	g_free (page->name);
 	page->name = g_strdup (name);
 }
 
@@ -809,28 +861,44 @@ npw_page_get_name (const NPWPage* page)
 	return page->name;
 }
 
+gboolean
+npw_page_set_language (NPWPage *page, gint language)
+{
+	if (page->language <= language)
+	{
+		page->language = language;
+		return TRUE;
+	}
+	else
+	{
+		return FALSE;
+	}
+}
+
 void
 npw_page_set_label (NPWPage* page, const gchar* label)
 {
+	g_free (page->label);
 	page->label = g_strdup (label);
 }
 
 const gchar*
 npw_page_get_label (const NPWPage* page)
 {
-	return page->label;
+	return page->language == 0 ? _(page->label) : page->label;
 }
 
 void
 npw_page_set_description (NPWPage* page, const gchar* description)
 {
+	g_free (page->description);
 	page->description = g_strdup (description);
 }
 
 const gchar*
 npw_page_get_description (const NPWPage* page)
 {
-	return page->description;
+	return page->language == 0 ? _(page->description) : page->description;
 }
 
 void
@@ -851,8 +919,31 @@ npw_page_foreach_property (const NPWPage* page, GFunc func, gpointer data)
 	g_list_foreach (page->properties, func, data);
 }
 
-void
+NPWProperty *
 npw_page_add_property (NPWPage* page, NPWProperty *prop)
 {
-	page->properties = g_list_append (page->properties, prop);
+	GList *find;
+	
+	find = g_list_find_custom (page->properties, prop, (GCompareFunc)npw_property_compare);
+	if (find == NULL)
+	{
+		page->properties = g_list_append (page->properties, prop);
+	}
+	else
+	{
+		NPWProperty* old_prop = (NPWProperty *)find->data;
+		
+		if (old_prop->language <= prop->language)
+		{
+			npw_property_free (old_prop);
+			find->data = prop;
+		}
+		else
+		{
+			npw_property_free (prop);
+			prop = old_prop;
+		}
+	}
+	
+	return prop;
 }
